@@ -67,6 +67,9 @@ class TreeSitterParser:
         elif self.language_name == 'scala':
             from .languages.scala import ScalaTreeSitterParser
             self.language_specific_parser = ScalaTreeSitterParser(self)
+        elif self.language_name == 'swift':
+            from .languages.swift import SwiftTreeSitterParser
+            self.language_specific_parser = SwiftTreeSitterParser(self)
 
 
 
@@ -110,6 +113,7 @@ class GraphBuilder:
             '.kt': TreeSitterParser('kotlin'),
             '.scala': TreeSitterParser('scala'),
             '.sc': TreeSitterParser('scala'),
+            '.swift': TreeSitterParser('swift'),
         }
         self.create_schema()
 
@@ -224,6 +228,9 @@ class GraphBuilder:
         if '.sc' in files_by_lang:
             from .languages import scala as scala_lang_module
             imports_map.update(scala_lang_module.pre_scan_scala(files_by_lang['.sc'], self.parsers['.sc']))
+        if '.swift' in files_by_lang:
+            from .languages import swift as swift_lang_module
+            imports_map.update(swift_lang_module.pre_scan_swift(files_by_lang['.swift'], self.parsers['.swift']))
             
         return imports_map
 
